@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -36,9 +36,7 @@ from weboob.core.repositories import IProgress
 from weboob.exceptions import BrowserUnavailable, BrowserIncorrectPassword, BrowserForbidden, \
                               BrowserSSLError, BrowserQuestion, BrowserHTTPSDowngrade, \
                               ModuleInstallError, ModuleLoadError, NoAccountsException, \
-                              ActionNeeded
-from weboob.capabilities.bank import TransferInvalidLabel, TransferInvalidAmount, TransferInvalidDate, \
-                                     TransferInvalidEmitter, TransferInvalidRecipient
+                              ActionNeeded, CaptchaQuestion
 from weboob.tools.value import Value, ValueBool, ValueFloat, ValueInt, ValueBackendPassword
 from weboob.tools.misc import to_unicode
 from weboob.tools.compat import unicode, long
@@ -265,7 +263,7 @@ class ConsoleApplication(Application):
     def register_backend(self, name, ask_add=True):
         try:
             backend = self.weboob.modules_loader.get_or_load_module(name)
-        except ModuleLoadError as e:
+        except ModuleLoadError:
             backend = None
 
         if not backend:
@@ -430,6 +428,8 @@ class ConsoleApplication(Application):
             v = klass(label=question, default=default, masked=masked, regexp=regexp, choices=choices, tiny=tiny)
 
         question = v.label
+        if v.description and v.description != v.label:
+            question = u'%s: %s' % (question, v.description)
         if v.id:
             question = u'[%s] %s' % (v.id, question)
 
@@ -501,10 +501,11 @@ class ConsoleApplication(Application):
 
         while True:
             if v.masked:
-                if sys.platform == 'win32':
-                    line = getpass.getpass(str(question))
-                else:
-                    line = getpass.getpass(question)
+                if sys.version_info.major < 3 and isinstance(question, unicode):
+                    question = question.encode(self.encoding)
+
+                line = getpass.getpass(question)
+                if sys.platform != 'win32':
                     if isinstance(line, bytes): # only for python2
                         line = line.decode(self.encoding)
             else:
@@ -570,19 +571,21 @@ class ConsoleApplication(Application):
                 print('Reading content from stdin... Type ctrl-D '
                           'from an empty line to stop.')
             text = self._readall()
-        return text
+        return to_unicode(text)
 
     def bcall_error_handler(self, backend, error, backtrace):
         """
         Handler for an exception inside the CallErrors exception.
 
-        This method can be overrided to support more exceptions types.
+        This method can be overridden to support more exceptions types.
         """
         if isinstance(error, BrowserQuestion):
             for field in error.fields:
                 v = self.ask(field)
                 if v:
                     backend.config[field.id].set(v)
+        elif isinstance(error, CaptchaQuestion):
+            print(u'Warning(%s): Captcha has been found on login page' % backend.name, file=self.stderr)
         elif isinstance(error, BrowserIncorrectPassword):
             msg = unicode(error)
             if not msg:
@@ -609,16 +612,6 @@ class ConsoleApplication(Application):
             print(u'Error(%s): this feature is not supported yet by this backend.' % backend.name, file=self.stderr)
             print(u'      %s   To help the maintainer of this backend implement this feature,' % (' ' * len(backend.name)), file=self.stderr)
             print(u'      %s   please contact us on the project mailing list' % (' ' * len(backend.name)), file=self.stderr)
-        elif isinstance(error, TransferInvalidAmount):
-            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'The transfer amount is invalid'), file=self.stderr)
-        elif isinstance(error, TransferInvalidLabel):
-            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'The transfer label is invalid'), file=self.stderr)
-        elif isinstance(error, TransferInvalidEmitter):
-            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'The transfer emitter is invalid'), file=self.stderr)
-        elif isinstance(error, TransferInvalidRecipient):
-            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'The transfer recipient is invalid'), file=self.stderr)
-        elif isinstance(error, TransferInvalidDate):
-            print(u'Error(%s): %s' % (backend.name, to_unicode(error) or 'The transfer execution date is invalid'), file=self.stderr)
         elif isinstance(error, UserError):
             print(u'Error(%s): %s' % (backend.name, to_unicode(error)), file=self.stderr)
         elif isinstance(error, MoreResultsAvailable):
@@ -654,15 +647,21 @@ class ConsoleApplication(Application):
         """
         ask_debug_mode = False
         more_results = set()
+        err = 0
+
         for backend, error, backtrace in errors.errors:
             if isinstance(error, MoreResultsAvailable):
                 more_results.add(backend.name)
             elif isinstance(error, ignore):
                 continue
-            elif self.bcall_error_handler(backend, error, backtrace):
-                ask_debug_mode = True
+            else:
+                err = 1
+                if self.bcall_error_handler(backend, error, backtrace):
+                    ask_debug_mode = True
 
         if ask_debug_mode:
             print(debugmsg, file=self.stderr)
         elif len(more_results) > 0:
             print('Hint: There are more results available for %s (use option -n or count command)' % (', '.join(more_results)), file=self.stderr)
+
+        return err
